@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from marshmallow.schema import Schema, SchemaOpts
 
 from . import fields
@@ -11,10 +13,15 @@ from marshmallow.decorators import (
 )
 from marshmallow.utils import EXCLUDE, INCLUDE, RAISE, pprint, missing
 from marshmallow.exceptions import ValidationError
-from distutils.version import LooseVersion
+from packaging.version import Version
 
-__version__ = "3.13.0"
-__version_info__ = tuple(LooseVersion(__version__).version)
+__version__ = "3.15.0"
+__parsed_version__ = Version(__version__)
+__version_info__: tuple[int, int, int] | tuple[
+    int, int, int, str, int
+] = __parsed_version__.release  # type: ignore[assignment]
+if __parsed_version__.pre:
+    __version_info__ += __parsed_version__.pre  # type: ignore[assignment]
 __all__ = [
     "EXCLUDE",
     "INCLUDE",
